# Pacifica Notifications Service
![PyPi](https://img.shields.io/pypi/v/pacifica-notifications.svg)
![Read the Docs](https://readthedocs.org/projects/pacifica-notifications/badge/?version=latest)
[![Build Status](https://travis-ci.org/pacifica/pacifica-notifications.svg?branch=master)](https://travis-ci.org/pacifica/pacifica-notifications)
[![Build Status](https://ci.appveyor.com/api/projects/status/c7jvfsgokp1txdso?svg=true)](https://ci.appveyor.com/project/dmlb2000/pacifica-notifications)
[![Maintainability](https://api.codeclimate.com/v1/badges/58b2e71aab6bd1af0609/maintainability)](https://codeclimate.com/github/pacifica/pacifica-notifications/maintainability)

## Docker Images
[![Docker Stars](https://img.shields.io/docker/stars/pacifica/notifications-backend.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/notifications-backend/general)
[![Docker Pulls](https://img.shields.io/docker/pulls/pacifica/notifications-backend.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/notifications-backend/general)
[![Docker Stars](https://img.shields.io/docker/stars/pacifica/notifications-frontend.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/notifications-frontend/general)
[![Docker Pulls](https://img.shields.io/docker/pulls/pacifica/notifications-frontend.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/notifications-frontend/general)

Pacifica notification service to catch internal state of data and notify on that state

This service is a (Pacifica Policy)[https://github.com/pacifica/pacifica-policy.git]
based routing mechanism for data subscribers to execute workflows based on the
availability of data in Pacifica.

## Documentation

For installation, configuration and usage documentation please
refer to the [Read the Docs](https://pacifica-notifications.readthedocs.io)
documentation.

* [Installation](docs/installation.md) documentation.
* [Configuration](docs/configuration.md) documentation.
* [Examples](docs/exampleusage.md) documentation.
